import { RouteRecordRaw } from 'vue-router';

/**
 * 路由meta对象参数说明
 * meta: {
 *      title:          菜单栏及 tagsView 栏、菜单搜索名称（国际化）
 *      isLink：        是否超链接菜单，开启外链条件，`1、isLink: 链接地址不为空`
 *      isHide：        是否隐藏此路由
 *      isKeepAlive：   是否缓存组件状态
 *      isAffix：       是否固定在 tagsView 栏上
 *      isIframe：      是否内嵌窗口，开启条件，`1、isIframe:true 2、isLink：链接地址不为空`
 *      roles：         当前路由权限标识，取角色管理。控制路由显示、隐藏。超级管理员：admin 普通角色：common
 *      icon：          菜单、tagsView 图标，阿里：加 `iconfont xxx`，fontawesome：加 `fa xxx`
 * }
 */

/**
 * 定义动态路由
 * 前端添加路由，请在顶级节点的 `children 数组` 里添加
 * @description 未开启 isRequestRoutes 为 true 时使用（前端控制路由），开启时第一个顶级 children 的路由将被替换成接口请求回来的路由数据
 * @description 各字段请查看 `/@/views/system/menu/component/addMenu.vue 下的 ruleForm`
 * @returns 返回路由菜单数据
 */
export const dynamicRoutes: Array<RouteRecordRaw> = [
	{
		path: '/',
		name: '/',
		component: () => import('/@/layout/index.vue'),
		redirect: '/home',
		meta: {
			isKeepAlive: true,
		},
		children: [
			{
				path: '/home',
				name: 'home',
				component: () => import('/@/views/home/index.vue'),
				meta: {
					title: '首页',
					isLink: '',
					isHide: false,
					isKeepAlive: true,
					isAffix: true,
					isIframe: false,
					icon: 'iconfont icon-shouye',
				},
			},
			{
				path: '/telslog',
				name: 'telslog',
				component: () => import('/@/layout/routerView/parent.vue'),
				redirect: '/telslog/callRecord',
				meta: {
					title: '电话记录',
					isLink: '',
					isHide: false,
					isKeepAlive: true,
					isAffix: false,
					isIframe: false,
					icon: 'ele-Phone',
				},
				children:[
					{
						path: '/telslog/callRecord',
						name: 'callRecord',
						component: () => import('/@/views/telslog/callRecord/index.vue'),
						meta: {
							title: '通讯记录',
							isLink: '',
							isHide: false,
							isKeepAlive: true,
							isAffix: false,
							isIframe: false,
							icon: 'ell-PhoneFiled',
						},
					},
					{
						path: '/telslog/blacklist',
						name: 'blacklist',
						component: () => import('/@/views/telslog/blacklist/index.vue'),
						meta: {
							title: '黑名单管理',
							isLink: '',
							isHide: false,
							isKeepAlive: true,
							isAffix: false,
							isIframe: false,
							icon: 'ell-Stamp',
						},
					},
				]
			},
			{
				path: '/deviceManagement',
				name: 'deviceManagement',
				component: () => import('/@/layout/routerView/parent.vue'),
				redirect: '/deviceManagement/tels',
				meta: {
					title: '设备管理',
					isLink: '',
					isHide: false,
					isKeepAlive: true,
					isAffix: false,
					isIframe: false,
					icon: 'iconfont icon-shuxingtu',
				},
				children: [
					{
						path: '/deviceManagement/tels',
						name: 'tels',
						component: () => import('/@/views/deviceManagement/tels/index.vue'),
						meta: {
							title: '话机管理',
							isLink: '',
							isHide: false,
							isKeepAlive: true,
							isAffix: false,
							isIframe: false,
							icon: 'iconfont icon-gerenzhongxin',
						},
					},
					{
						path: '/deviceManagement/telsGroup',
						name: 'telsGroup',
						component: () => import('/@/views/deviceManagement/telsGroup/index.vue'),
						meta: {
							title: '分机组管理',
							isLink: '',
							isHide: false,
							isKeepAlive: true,
							isAffix: false,
							isIframe: false,
							icon: 'iconfont icon-icon-',
						},
					},
					{
						path: '/deviceManagement/ivrCategroy',
						name: 'ivrCategroy',
						component: () => import('/@/views/deviceManagement/ivrCategroy/index.vue'),
						meta: {
							title: 'IVR分类管理',
							isLink: '',
							isHide: false,
							isKeepAlive: true,
							isAffix: false,
							isIframe: false,
							icon: 'iconfont icon-AIshiyanshi',
						},
					},
					{
						path: '/deviceManagement/ivrList',
						name: 'ivrList',
						component: () => import('/@/views/deviceManagement/ivrList/index.vue'),
						meta: {
							title: 'IVR管理',
							isLink: '',
							isHide: false,
							isKeepAlive: true,
							isAffix: false,
							isIframe: false,
							icon: 'iconfont icon-AIshiyanshi',
						},
					},
				]
			},
			{
				path: '/system',
				name: 'system',
				component: () => import('/@/layout/routerView/parent.vue'),
				redirect: '/system/user',
				meta: {
					title: '系统设置',
					isLink: '',
					isHide: false,
					isKeepAlive: true,
					isAffix: false,
					isIframe: false,
					icon: 'iconfont icon-xitongshezhi',
				},
				children: [
					{
						path: '/system/institutionalUsers',
						name: 'institutionalUsers',
						component: () => import('/@/layout/routerView/parent.vue'),
						redirect: '/system/institutionalUsers',
						meta: {
							title: '机构用户',
							isLink: '',
							isHide: false,
							isKeepAlive: true,
							isAffix: false,
							isIframe: false,
							icon: 'iconfont icon-icon-',
						},
						children: [
							{
								path: '/system/institutionalUsers/user',
								name: 'user',
								component: () => import('/@/views/system/institutionalUsers/user/index.vue'),
								meta: {
									title: '用户管理',
									isLink: '',
									isHide: false,
									isKeepAlive: true,
									isAffix: false,
									isIframe: false,
									icon: 'iconfont icon-bolangneng',
								},
							},
							{
								path: '/system/institutionalUsers/roles',
								name: 'roles',
								component: () => import('/@/views/system/institutionalUsers/roles/index.vue'),
								meta: {
									title: '角色管理',
									isLink: '',
									isHide: false,
									isKeepAlive: true,
									isAffix: false,
									isIframe: false,
									icon: 'iconfont icon-bolangneng',
								},
							},
						]
					},
					{
						path: '/system/systemParameter',
						name: 'systemParameter',
						component: () => import('/@/views/system/systemParameter/index.vue'),
						meta: {
							title: '系统参数',
							isLink: '',
							isHide: false,
							isKeepAlive: true,
							isAffix: false,
							isIframe: false,
							icon: 'iconfont icon-wendu',
						},
					},
					{
						path: '/system/menu',
						name: 'systemMenu',
						component: () => import('/@/views/system/menu/index.vue'),
						meta: {
							title: '菜单管理',
							isLink: '',
							isHide: false,
							isKeepAlive: true,
							isAffix: false,
							isIframe: false,
							icon: 'iconfont icon-caidan',
						},
					},
					{
						path: '/system/public',
						name: 'public',
						component: () => import('/@/views/system/public/index.vue'),
						meta: {
							title: '公用',
							isLink: '',
							isHide: true,
							isKeepAlive: true,
							isAffix: false,
							isIframe: false,
							icon: 'iconfont icon-icon-',
						},
					},
					{
						path: '/system/organizational',
						name: 'organizational',
						component: () => import('/@/views/system/organizational/index.vue'),
						meta: {
							title: '组织架构管理',
							isLink: '',
							isHide: false,
							isKeepAlive: true,
							isAffix: false,
							isIframe: false,
							icon: 'iconfont icon-icon-',
						},
					},
					// {
					// 	path: '/system/dic',
					// 	name: 'systemDic',
					// 	component: () => import('/@/views/system/dic/index.vue'),
					// 	meta: {
					// 		title: '字典管理',
					// 		isLink: '',
					// 		isHide: true,
					// 		isKeepAlive: true,
					// 		isAffix: false,
					// 		isIframe: false,
					// 		icon: 'ele-SetUp',
					// 	},
					// },
				],
			}
		],
	},
];

/**
 * 定义404、401界面
 * @link 参考：https://next.router.vuejs.org/zh/guide/essentials/history-mode.html#netlify
 */
export const notFoundAndNoPower = [
	{
		path: '/401',
		name: 'noPower',
		component: () => import('/@/views/error/401.vue'),
		meta: {
			title: '无权限',
			isHide: true,
		},
	},
	{
		path: '/:catchAll(.*)',
		name: 'notFound',
		component: () => import('/@/views/error/404.vue'),
		meta: {
			title: '404',
			isHide: true,
		},
	},
];

/**
 * 定义静态路由（默认路由）
 * 此路由不要动，前端添加路由的话，请在 `dynamicRoutes 数组` 中添加
 * @description 前端控制直接改 dynamicRoutes 中的路由，后端控制不需要修改，请求接口路由数据时，会覆盖 dynamicRoutes 第一个顶级 children 的内容（全屏，不包含 layout 中的路由出口）
 * @returns 返回路由菜单数据
 */
export const staticRoutes: Array<RouteRecordRaw> = [
	{
		path: '/login',
		name: 'login',
		component: () => import('/@/views/login/index.vue'),
		meta: {
			title: '登录',
		},
	},
	{
		path: '/changePwd',
		name: 'changePwd',
		component: () => import('/@/views/changePwd/index.vue'),
		meta: {
			title: '修改密码',
		},
	}
];
